@@ -5,7 +5,7 @@ package App::SpeedTest;
 use strict;
 use warnings;
 
-our $VERSION = "0.17";
+our $VERSION = "0.18";
 
 1;
 __END__
@@ -122,6 +122,12 @@ Generate a very short report easy to paste in e.g. IRC channels.
  $ speedtest -1Qv0
  DL:   40.721 Mbit/s, UL:   30.307 Mbit/s
 
+=item -B | --bytes
+X<-B>
+X<--bytes>
+
+Report throughput in Mbyte/s instead of Mbit/s
+
 =item -C | --csv
 X<-C>
 X<--csv>
@@ -144,6 +150,36 @@ The reported fields are
  "2015-01-24 17:15:09",4358,63.97,40,D,93.45,30.39,136.93
  "2015-01-24 17:15:14",4358,63.97,40,U,92.67,31.10,143.06
 
+=item -P | --prtg
+X<-P>
+X<--prtg>
+
+Generate the measurements in XML suited for PRTG
+
+ $ speedtest -P
+ <?xml version="1.0" encoding="UTF-8" ?>
+ <prtg>
+   <text>Testing from My ISP (10.20.30.40)</text>
+   <result>
+     <channel>Ping</channel>
+     <customUnit>ms</customUnit>
+     <float>1</float>
+     <value>56.40</value>
+     </result>
+   <result>
+     <channel>Download</channel>
+     <customUnit>Mbit/s</customUnit>
+     <float>1</float>
+     <value>38.34</value>
+     </result>
+   <result>
+     <channel>Upload</channel>
+     <customUnit>Mbit/s</customUnit>
+     <float>1</float>
+     <value>35.89</value>
+     </result>
+   </prtg>
+
 =item -l | --list
 X<-l>
 X<--list>
